@@ -1,5 +1,7 @@
 #!/bin/bash
 
+set -e
+
 CONDA_INSTALL="conda install -q -y"
 PIP_INSTALL="pip install -q"
 
@@ -41,7 +43,7 @@ if [ "$PYTHON" == "pypy" ]; then
   $PIP_INSTALL sphinx==1.5.1 sphinx_rtd_theme pygments
 else
   $CONDA_INSTALL sphinx=1.5.1 sphinx_rtd_theme pygments
-  if [ "$PYTHON" \< "3.4" ]; then
+  if [ "x$PYTHON" != "x" -a "$PYTHON" \< "3.4" -a "$WHEEL" != "yes" ]; then
     $CONDA_INSTALL enum34
   fi
 fi
